@@ -4,58 +4,46 @@
 <context>
     <name>Board</name>
     <message>
-        <location filename="../src/board.cpp" line="83"/>
-        <location filename="../src/board.cpp" line="872"/>
         <source>Details</source>
         <translation>Подробиці</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="112"/>
         <source>Clear</source>
         <translation>Очистити</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="126"/>
         <source>Guess</source>
         <translation>Здогад</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="156"/>
         <source>Found</source>
         <translation>Знайти</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="295"/>
         <source>Normal</source>
         <translation>Звичайна</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="295"/>
         <source>Large</source>
         <translation>Велика</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="314"/>
         <source>Missed</source>
         <translation>Невдача</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="448"/>
         <source>Error</source>
         <translation>Помилка</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="614"/>
         <source>Success</source>
         <translation>Успішно</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="614"/>
         <source>Game Over</source>
         <translation>Гру завершено</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="793"/>
         <source>%1 of %n point(s)</source>
         <translation>
             <numerusform>%1 з %n очка</numerusform>
@@ -64,7 +52,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="795"/>
         <source>3 of %n point(s)</source>
         <translation type="unfinished">
             <numerusform></numerusform>
@@ -73,7 +60,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="797"/>
         <source>2 of %n point(s)</source>
         <translation type="unfinished">
             <numerusform></numerusform>
@@ -82,7 +68,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="799"/>
         <source>1 of %n point(s)</source>
         <translation type="unfinished">
             <numerusform></numerusform>
@@ -91,7 +76,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="801"/>
         <source>0 of %n point(s)</source>
         <translation type="unfinished">
             <numerusform></numerusform>
@@ -100,7 +84,6 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/board.cpp" line="805"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n очко</numerusform>
@@ -109,7 +92,6 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="881"/>
         <source>The maximum score was calculated from the following thirty words:</source>
         <translation>Максимальна оцінка вирахувана з наступних тридцяти слів:</translation>
     </message>
@@ -117,12 +99,10 @@
 <context>
     <name>Clock</name>
     <message>
-        <location filename="../src/clock.cpp" line="93"/>
         <source>m:ss</source>
         <translation>m:ss</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="154"/>
         <source>%n guesses(s)</source>
         <translation>
             <numerusform>%n здогадка</numerusform>
@@ -131,12 +111,10 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="280"/>
         <source>+%1</source>
         <translation>+%1</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/clock.cpp" line="344"/>
         <source>%n strike(s)</source>
         <translation>
             <numerusform>%n хід</numerusform>
@@ -145,72 +123,58 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="519"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="520"/>
         <source>Classic</source>
         <translation>Класика</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="521"/>
         <source>Refill</source>
         <translation>Поповнення</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="522"/>
         <source>Stamina</source>
         <translation>Витривалість</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="523"/>
         <source>Strikeout</source>
         <translation>Три удари</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="524"/>
         <source>Allotment</source>
         <translation>Квота 30</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="525"/>
         <source>Discipline</source>
         <translation>Дисципліна</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="533"/>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Підрахунок ведеться від 30 секунд і збільшується за правильні здогадки.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="534"/>
         <source>Counts down from 3 minutes.</source>
         <translation>Підрахунок ведеться від 3 хвилин.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="535"/>
         <source>Counts down from 30 seconds and refills on correct guesses.</source>
         <translation>Підрахунок ведеться від 30 секунд і поповнюється за правильні здогадки.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="536"/>
         <source>Counts down from 45 seconds and pauses on correct guesses.</source>
         <translation>Підрахунок ведеться від 45 секунд і призупиняється за правильні здогадки.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="537"/>
         <source>Game ends after 3 incorrect guesses.</source>
         <translation>Гра завершується після 3 неправильних здогадок.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="538"/>
         <source>Game ends after 30 guesses.</source>
         <translation>Гра завершується після 30 здогадок.</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="539"/>
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Підрахунок ведеться від 30 секунд і зростає або зменшується за правильні або неправильні здогадки.</translation>
     </message>
@@ -218,12 +182,10 @@
 <context>
     <name>Generator</name>
     <message>
-        <location filename="../src/generator.cpp" line="273"/>
         <source>Unable to read dice from file.</source>
         <translation>Не вдалось прочитати розкладку з файла.</translation>
     </message>
     <message>
-        <location filename="../src/generator.cpp" line="351"/>
         <source>Unable to read word list from file.</source>
         <translation>Не вдалось прочитати список слів з файла.</translation>
     </message>
@@ -231,53 +193,42 @@
 <context>
     <name>LanguageDialog</name>
     <message>
-        <location filename="../src/language_dialog.cpp" line="44"/>
         <source>Board Language</source>
         <translation>Параметри мови</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="67"/>
         <source>Custom</source>
         <translation>Власна</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="75"/>
-        <location filename="../src/language_dialog.cpp" line="82"/>
         <source>Choose...</source>
         <translation>Вибрати...</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="91"/>
         <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
         <translation>&lt;b&gt;Заувага:&lt;/b&gt; Ці параметри набудуть сили після запуску нової гри.</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="103"/>
         <source>Language:</source>
         <translation>Мова:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="106"/>
         <source>Dice:</source>
         <translation>Розкладка:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="110"/>
         <source>Word list:</source>
         <translation>Список слів:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="114"/>
         <source>Dictionary:</source>
         <translation>Словник:</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="198"/>
         <source>Choose Dice File</source>
         <translation>Вибрати файл розкладки</translation>
     </message>
     <message>
-        <location filename="../src/language_dialog.cpp" line="214"/>
         <source>Choose Word List File</source>
         <translation>Вибрати файл списку слів</translation>
     </message>
@@ -285,22 +236,18 @@
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="52"/>
         <source>Select application language:</source>
         <translation>Вибрати мову програми:</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="55"/>
         <source>&lt;System Language&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="175"/>
         <source>Note</source>
         <translation>Примітка</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="175"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Перезапустіть програму, щоб зміна мови вступила в силу.</translation>
     </message>
@@ -308,42 +255,34 @@
 <context>
     <name>NewGameDialog</name>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="81"/>
         <source>New Game</source>
         <translation>Нова гра</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="146"/>
         <source>Amount of Words:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="147"/>
         <source>Minimum Word Length:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="202"/>
         <source>Low</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="203"/>
         <source>Medium</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="204"/>
         <source>High</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="205"/>
         <source>Random</source>
         <translation type="unfinished"></translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/new_game_dialog.cpp" line="222"/>
         <source>%n letter(s)</source>
         <translation type="unfinished">
             <numerusform></numerusform>
@@ -355,42 +294,34 @@
 <context>
     <name>ScoresDialog</name>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="52"/>
         <source>High Scores</source>
         <translation>Найвищий рахунок</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="78"/>
         <source>&lt;b&gt;Name&lt;/b&gt;</source>
         <translation>&lt;b&gt;Назва&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="79"/>
         <source>&lt;b&gt;Score&lt;/b&gt;</source>
         <translation>&lt;b&gt;Рахунок&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="80"/>
         <source>&lt;b&gt;Date&lt;/b&gt;</source>
         <translation>&lt;b&gt;Дата&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="81"/>
         <source>&lt;b&gt;Timer&lt;/b&gt;</source>
         <translation>&lt;b&gt;Таймер&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="85"/>
         <source>#%1</source>
         <translation>№%1</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
         <source>Question</source>
         <translation>Запитання</translation>
     </message>
     <message>
-        <location filename="../src/scores_dialog.cpp" line="202"/>
         <source>Clear high scores?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -398,312 +329,246 @@
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/main.cpp" line="32"/>
         <source>Tanglet</source>
         <translation>Tanglet</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="301"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Пауза&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Клацніть, щоб відновити гру.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="307"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="312"/>
         <source>Click to start a new game.</source>
         <translation>Натисніть, щоб розпочати нову гру.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="318"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Зачекайте&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Генерування нової розкладки...&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="323"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="328"/>
         <source>&amp;Game</source>
         <translation>&amp;Гра</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="329"/>
         <source>New &amp;Game...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="329"/>
         <source>Ctrl+Shift+N</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="330"/>
         <source>&amp;New Roll</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="331"/>
         <source>&amp;Choose...</source>
         <translation>&amp;Вибрати...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="332"/>
         <source>&amp;Share...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="334"/>
         <source>&amp;End</source>
         <translation>&amp;Завершити</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="337"/>
         <source>&amp;Pause</source>
         <translation>&amp;Пауза</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="339"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="344"/>
         <source>&amp;Details</source>
         <translation>&amp;Подробиці</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="346"/>
         <source>&amp;High Scores</source>
         <translation>&amp;Найвищі рахунки</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="348"/>
         <source>&amp;Quit</source>
         <translation>&amp;Вийти</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="348"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="353"/>
         <source>&amp;Settings</source>
         <translation>&amp;Параметри</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="354"/>
         <source>Show &amp;Maximum Score</source>
         <translation>Показати &amp;найбільший рахунок</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="356"/>
         <source>&amp;Never</source>
         <translation>&amp;Ніколи</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="357"/>
         <source>&amp;End Of Game</source>
         <translation>&amp;Кінець гри</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="358"/>
         <source>&amp;Always</source>
         <translation>&amp;Завжди</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="366"/>
         <source>Show Missed &amp;Words</source>
         <translation>Показувати невдалі &amp;слова</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="369"/>
         <source>Show Word &amp;Counts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="373"/>
         <source>&amp;Board Language...</source>
         <translation>Мова роз&amp;кладки...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="375"/>
         <source>Application &amp;Language...</source>
         <translation>Мова про&amp;грами...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="379"/>
         <source>&amp;Help</source>
         <translation>&amp;Довідка</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="380"/>
         <source>&amp;Controls</source>
         <translation>&amp;Керування</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="382"/>
         <source>&amp;About</source>
         <translation>Про &amp;програму</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="384"/>
         <source>About &amp;Hspell</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="386"/>
         <source>About &amp;Qt</source>
         <translation>Про &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
         <source>About &amp;SCOWL</source>
         <translation>Про &amp;SCOWL</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="470"/>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="468"/>
         <source>Tanglet %1</source>
         <translation>Tanglet %1</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="466"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="469"/>
         <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
         <translation>Варіант гри для одного гравця &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="471"/>
         <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Розповсюджується за умовами ліцензії &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="472"/>
         <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="473"/>
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="480"/>
         <source>About Hspell</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="487"/>
         <source>About SCOWL</source>
         <translation>Про SCOWL</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="516"/>
         <source>Import Game</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="518"/>
-        <location filename="../src/window.cpp" line="578"/>
         <source>Tanglet Games (*.tanglet)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="533"/>
-        <location filename="../src/window.cpp" line="548"/>
-        <location filename="../src/window.cpp" line="557"/>
-        <location filename="../src/window.cpp" line="787"/>
         <source>Unable to start requested game.</source>
         <translation>Не вдалось запустити запитану гру.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="566"/>
-        <location filename="../src/window.cpp" line="787"/>
         <source>Error</source>
         <translation>Помилка</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="576"/>
         <source>Export Game</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="623"/>
         <source>Question</source>
         <translation>Запитання</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="623"/>
         <source>End the current game?</source>
         <translation>Завершити поточну гру?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="662"/>
         <source>Details</source>
         <translation>Подробиці</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Board Size:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Normal</source>
         <translation>Звичайна</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="668"/>
         <source>Large</source>
         <translation>Велика</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="669"/>
         <source>Word Density:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="670"/>
         <source>Word Length:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="670"/>
         <source>%1 or more letters</source>
         <translation>%1 або більше букв</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="671"/>
         <source>Game Type:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="672"/>
         <source>Description:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="702"/>
         <source>Controls</source>
         <translation>Керування</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="702"/>
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Гра мишею:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Вибрати слово:&lt;/b&gt; Клацання на буквах слова.&lt;br&gt;&lt;b&gt;Зробити припущення:&lt;/b&gt; Клацнути на останній вибраній букві.&lt;br&gt;&lt;b&gt;Викреслити букви:&lt;/b&gt; Клацнути на раніше вибраній букві.&lt;br&gt;&lt;b&gt;Очистити слово:&lt;/b&gt; Двічі клацнути на першій букві.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Гра з клавіатури:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Вибрати слово:&lt;/b&gt; Ввести букви слова.&lt;br&gt;&lt;b&gt;Зробити припущення:&lt;/b&gt; Натиснути клавішу «Enter».&lt;br&gt;&lt;b&gt;Очистити слово:&lt;/b&gt; Натиснути «Ctrl+Backspace».&lt;/p&gt;</translation>
     </message>
@@ -711,27 +576,22 @@
 <context>
     <name>WordCounts</name>
     <message>
-        <location filename="../src/word_counts.cpp" line="41"/>
         <source>Letters:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="41"/>
         <source>Found:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="117"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="122"/>
         <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/word_counts.cpp" line="124"/>
         <source>%1&lt;br&gt;%2/%3</source>
         <translation type="unfinished"></translation>
     </message>
@@ -739,7 +599,6 @@
 <context>
     <name>WordTree</name>
     <message numerus="yes">
-        <location filename="../src/word_tree.cpp" line="93"/>
         <source>%n point(s)</source>
         <translation>
             <numerusform>%n очко</numerusform>
@@ -748,4 +607,15 @@
         </translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Word finding game</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A game file to play.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
